@@ -10,7 +10,7 @@ else:
 
 from datetime import datetime
 
-__version__ = '0.5.0'
+__version__ = '0.7.0'
 URL = 'https://d3design.tools'
 
 
@@ -25,12 +25,11 @@ class Client(object):
         self._user = user
         self._apiToken = apiToken
         # Check credentials and initialize user.
-        response = self.__post(URL+'/cloud_api_initialize',{'version':__version__})
+        response = self.__post(URL+'/api_initialize',{'version':__version__})
         if response['valid']:
             print('INFO [client]: Connected to D3 Cloud.')
         if not response['valid']:
             print(response['info'])
-            sys.exit()
 
     # Private.
 
@@ -80,12 +79,12 @@ class Client(object):
         if self.simulationState(projectName,simulationName) != 'finished':
             print('WARNING [client]: Simulation must be on "finished" state to download its results.')
             return
-        response = self.__post(URL+'/cloud_api_valid_results_size_limit',{'projectName':projectName,'simulationName':simulationName,'extension':'csv','cases':cases})
+        response = self.__post(URL+'/api_valid_results_size_limit',{'projectName':projectName,'simulationName':simulationName,'extension':'csv','cases':cases})
         if response['valid']:
             if not response['validSize']:
                 print('ERROR [client]: Requested results exceed download size limit, please select fewer cases.')
                 return
-            response = self.__post(URL+'/cloud_api_downloadResults',{'projectName':projectName,'simulationName':simulationName,'cases':cases,'resultsType':resultsType}, returnRaw=True)
+            response = self.__post(URL+'/api_downloadResults',{'projectName':projectName,'simulationName':simulationName,'cases':cases,'resultsType':resultsType}, returnRaw=True)
             if response['valid']:
                 with open(localPath,'wb') as f:
                     f.write(response['content'])
@@ -105,7 +104,7 @@ class Client(object):
         Returns:
             boolean: Wether new project creation request was successful or not.
         """
-        response = self.__post(URL+'/cloud_api_newProject',{'projectName':projectName})
+        response = self.__post(URL+'/api_newProject',{'projectName':projectName})
         print('INFO [client|newProject]:',response['info'])
         return response['valid']
 
@@ -118,7 +117,7 @@ class Client(object):
         Returns:
             boolean: Wether project deletion was successful or not.
         """
-        response = self.__post(URL+'/cloud_api_deleteProject',{'projectName':projectName})
+        response = self.__post(URL+'/api_deleteProject',{'projectName':projectName})
         print('INFO [client|deleteProject]:',response['info'])
         return response['valid']
 
@@ -128,8 +127,8 @@ class Client(object):
         Returns:
             dict: Dictionary matching each project name with a list of its simulations information (type, points, state, description, etc).
         """
-        info = self.__post(URL+'/cloud_api_projectsInfo') # This contains 'projectsInfo' and 'deletedProjects' keys.
-        return info.get('projectsInfo',{})
+        info = self.__post(URL+'/api_projectsInfo')
+        return info.get('projectsSimulationInfo',{})
 
     def newSimulation(self,projectName,simulationName,simulationType,simulationGeometries,simulationMatrix,simulationSettings):
         """Submit new simulation.
@@ -210,21 +209,22 @@ class Client(object):
                 return False
 
         # Wait until (non-blocking) geometry upload finishes.
-        status = 'processing'
-        while status == 'processing':
+        status = 'waiting'
+        while status in ['waiting','processing']:
             response = self.__post(
-                URL+'/cloud_api_processGeometriesInfo',
+                URL+'/api_processGeometriesInfo',
                 {
                     'projectName':projectName,
                     'simulationName':simulationName
                 }
             )
             status = response['status']
-            print('INFO [client|newSimulation]: Waiting for geometries to be processed, this make take several minutes. Please wait.')
-            time.sleep(10)
+            message = response['message']
+            print('INFO [client|newSimulation]:',message)
+            time.sleep(3)
 
-        if status != 'ok':
-            print('ERROR [client|newSimulation]: '+status)
+        if status != 'finished':
+            print('ERROR [client|newSimulation]: '+message)
             return False
 
         # Send request with matrix and simulation settings.
@@ -235,7 +235,7 @@ class Client(object):
             simulationSettings = f.read()
 
         response = self.__post(
-            URL+'/cloud_api_newSimulation',
+            URL+'/api_newSimulation',
             {
                 'simulationType':simulationType,
                 'projectName':projectName,
@@ -258,7 +258,7 @@ class Client(object):
         Return:
             boolean: Wether simulation deletion was successful or not.
         """
-        response = self.__post(URL+'/cloud_api_deleteSimulation',{'projectName':projectName,'simulationName':simulationName})
+        response = self.__post(URL+'/api_deleteSimulation',{'projectName':projectName,'simulationName':simulationName})
         print('INFO [client|deleteSimulation]:',response['info'])
         return response['valid']
 
@@ -298,7 +298,7 @@ class Client(object):
         if self.simulationState(projectName,simulationName) != 'finished':
             print('WARNING [client|downloadTable]: Simulation must be on "finished" state to download its results.')
             return
-        response = self.__post(URL+'/cloud_api_downloadTable',{'projectName':projectName,'simulationName':simulationName})
+        response = self.__post(URL+'/api_downloadTable',{'projectName':projectName,'simulationName':simulationName})
         if response['valid']:
             return response['results']
         else:
